@@ -15,4 +15,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .compile import prepare_ir
+from .compile import compile
