@@ -42,7 +42,6 @@ class TensorFlowAdaptor(Adaptor):
         "MatMul": "matmul",
         "Pad": "pad"
     }
-
     def __init__(self, framework_specific_info):
         super().__init__(framework_specific_info)
 
@@ -107,10 +106,11 @@ class TensorFlowAdaptor(Adaptor):
     
     @dump_elapsed_time(customized_msg="Model training")
     def train(self, model, dataloader, optimizer_tuple,
-                criterion_tuple, hooks, **kwargs):
+              criterion_tuple, hooks, postprocess, **kwargs):
         # check model is savedmodel or not
         import tensorflow as tf
         from neural_compressor.model.model import get_model_type
+        tf.random.set_seed(1)
         self.model_type = get_model_type(model._model)
         optimizer = optimizer_tuple[0](**optimizer_tuple[1])
         criterion = criterion_tuple[0](**criterion_tuple[1])
@@ -119,6 +119,7 @@ class TensorFlowAdaptor(Adaptor):
         epochs = kwargs['kwargs'].get('epoch', None)
         iters = kwargs['kwargs'].get('iteration', None)
         callbacks = kwargs['kwargs'].get('callbacks', None)
+        execution_mode = kwargs['kwargs'].get('execution_mode', None)
         distributed = getattr(dataloader, 'distributed', False)
         from neural_compressor.experimental.common.criterion import TensorflowKnowledgeDistillationLoss
         if isinstance(criterion, TensorflowKnowledgeDistillationLoss):
@@ -143,22 +144,22 @@ class TensorFlowAdaptor(Adaptor):
                             raise AttributeError("The traning dataloader's iteration is"
                                                 "different between processes, please reset dataloader's batch_size.") 
 
-        @tf.function
-        def training_step(first_batch):
+        def training_step(x, y, first_batch):
             with tf.GradientTape() as tape:
                 tape.watch(input_model.trainable_variables)
-                y_ = input_model(x)
+                y_ = input_model(x, training=True)
                 loss_value = criterion(y, y_)
             tape = self.hvd.DistributedGradientTape(tape) if distributed else tape
             # Get gradient
-            grads = tape.gradient(loss_value, input_model.trainable_variables)
+            grads = tape.gradient(loss_value, input_model.trainable_variables) # pylint: disable=no-member
             # Optimize the model
-            optimizer.apply_gradients(zip(grads, input_model.trainable_variables))
+            optimizer.apply_gradients(zip(grads, input_model.trainable_variables)) # pylint: disable=no-member
             if distributed and first_batch:
                 self.hvd.broadcast_variables(input_model.variables, root_rank=0)
                 self.hvd.broadcast_variables(optimizer.variables(), root_rank=0)
             return loss_value
-
+        
+        training_step = training_step if execution_mode=='eager' else tf.function(training_step)
         if start_epochs is not None and end_epochs is not None:
             epochs = end_epochs - start_epochs
         for epoch in range(epochs):
@@ -166,12 +167,13 @@ class TensorFlowAdaptor(Adaptor):
             epoch_loss_avg = tf.keras.metrics.Mean()
             hooks['on_epoch_begin'](epoch)         # on_epoch_begin hook
             # Training loop
-            for iter, (x, y) in enumerate(dataloader):
+            for iter, data in enumerate(dataloader):
+                x, y = postprocess(data) if postprocess is not None else data
                 hooks['on_batch_begin'](iter)      # on_batch_begin hook
                 cnt += 1
                 if hasattr(criterion, "teacher_model_forward"):
                     criterion.teacher_model_forward(x)
-                loss_value = training_step(iter == 0)
+                loss_value = training_step(x, y, iter==0)
                 # Track progress
                 epoch_loss_avg.update_state(loss_value)  # Add current batch loss
                 hooks['on_batch_end']()            # on_batch_end hook
@@ -181,14 +183,22 @@ class TensorFlowAdaptor(Adaptor):
             hooks['on_epoch_end']()                # on_epoch_end hook
             # End epoch
             train_loss_results.append(epoch_loss_avg.result())
-            if not distributed or self.hvd.local_rank() == 0:
-                logger.info("Epoch {:03d}: Loss: {:.3f}".format(epoch+1, epoch_loss_avg.result()))
+            if distributed:
+                logger.info("Epoch-{:03d} training on rank {!s} have been done." \
+                    .format(epoch+1, self.hvd.allgather_object(self.hvd.rank())))
+            logger.info("Epoch {:03d}: Loss: {:.3f}".format(epoch+1, epoch_loss_avg.result()))
 
         hooks['post_epoch_end']()                  # post_epoch_end hook
         model._sess = None
         if not isinstance(criterion, TensorflowKnowledgeDistillationLoss):
-            if not distributed or self.hvd.rank() == 0:
-                # Update the input model with pruned weights manually due to keras API limitation.
+            if distributed:
+                if self.hvd.rank() == 0:
+                    # Update the input model with pruned weights manually due to keras API limitation.
+                    input_model.save(model._model)
+                rank_list = self.hvd.allgather_object(self.hvd.rank())
+                logger.info(f"rank 0 has saved the pruned model to '{model._model}',"
+                            f"all ranks {rank_list} ready.")
+            else:
                 input_model.save(model._model)
         else:
             input_model.save('distillation_model')
@@ -234,7 +244,9 @@ class TensorFlowAdaptor(Adaptor):
                     for i in range(len(list_len_dataloader)-1):
                         if list_len_dataloader[i] != list_len_dataloader[i+1]:
                             raise AttributeError("The evaluation dataloader's iteration is"
-                                                "different between processes, please reset dataloader's batch_size.") 
+                                                 "different between processes, please reset dataloader's batch_size.")
+            logger.info("Rank {!s} dataloaders' data distribution balance check for evaluation have been finnished." \
+                .format(hvd.allgather_object(hvd.rank())))
         if tensorboard:
             from .tf_utils.graph_rewriter.graph_util import GraphAnalyzer
             from tensorflow.python.framework import tensor_util
@@ -494,10 +506,12 @@ class TensorFlowAdaptor(Adaptor):
                                         bf16_ops=self.bf16_ops,
                                         data_loader=data_loader).convert()
             except Exception: # pragma: no cover
+                from .tf_utils.util import get_model_input_shape
+                batch_size = get_model_input_shape(model)
                 logger.warning(
                         "Fail to forward with batch size={}, set to {} now.".
-                        format(batch_size, 1))
-                data_loader.batch(1)
+                        format(batch_size, batch_size))
+                data_loader.batch(batch_size)
                 self.quantize_config['calib_iteration'] = calib_sampling_size
                 converted_model = GraphConverter(model,
                                         qt_config=self.quantize_config,
@@ -511,9 +525,9 @@ class TensorFlowAdaptor(Adaptor):
               calib_sampling_size % data_loader.batch_size != 0:
                 iter = self.quantize_config['calib_iteration']
                 logger.warning(
-                    "Please Note that calibration sampling size {} \
-                    isn't divisible exactly by batch size {}. \
-                    So the real sampling size is {}.".
+                    "Please note that calibration sampling size {} " \
+                    "isn't divisible exactly by batch size {}. " \
+                    "So the real sampling size is {}.".
                     format(calib_sampling_size, data_loader.batch_size,
                            data_loader.batch_size * iter))
             converted_model = GraphConverter(model,
@@ -1046,6 +1060,8 @@ class TensorFlowAdaptor(Adaptor):
                                             recover_config=q_config)
 
         return converter.convert_without_calib()
+
+
 @adaptor_registry
 class Tensorflow_ITEXAdaptor(TensorFlowAdaptor):
     def __init__(self, framework_specific_info):
@@ -1113,9 +1129,9 @@ class Tensorflow_ITEXAdaptor(TensorFlowAdaptor):
               calib_sampling_size % data_loader.batch_size != 0:
                 iter = self.quantize_config['calib_iteration']
                 logger.warning(
-                    "Please Note that calibration sampling size {} \
-                    isn't divisible exactly by batch size {}. \
-                    So the real sampling size is {}.".
+                    "Please note that calibration sampling size {} " \
+                    "isn't divisible exactly by batch size {}. " \
+                    "So the real sampling size is {}.".
                     format(calib_sampling_size, data_loader.batch_size,
                            data_loader.batch_size * iter))
             converted_model = GraphConverter(model,
