@@ -19,7 +19,6 @@
 import logging
 from neural_compressor.adaptor.tf_utils.graph_rewriter.graph_util import GraphAnalyzer
 from neural_compressor.utils.utility import dump_elapsed_time
-
 from .fuse_column_wise_mul import FuseColumnWiseMulOptimizer
 from .remove_training_nodes import RemoveTrainingNodesOptimizer
 from .split_shared_input import SplitSharedInputOptimizer
@@ -39,6 +38,8 @@ from .fuse_conv_with_math import FuseConvWithMathOptimizer
 from .fuse_biasadd_add import FuseBiasAddAndAddOptimizer
 from .switch_optimizer import SwitchOptimizer
 from .move_squeeze_after_relu import MoveSqueezeAfterReluOptimizer
+from .convert_nan_to_random import ConvertNanToRandom
+from .expanddims_optimizer import ExpandDimsOptimizer
 
 class PreOptimization():
     def __init__(self, model, optimization):
@@ -92,11 +93,9 @@ class PreOptimization():
         self._tmp_graph_def = ConvertLayoutOptimizer(
             self.model.graph_def, output_node_names).do_transformation()
 
-        self._tmp_graph_def = MoveSqueezeAfterReluOptimizer(
-            self.model.graph_def).do_transformation()
-        
         self._tmp_graph_def = GrapplerOptimizer(
             self._tmp_graph_def, output_node_names, self.optimization).do_transformation()
+
         self._tmp_graph_def = SwitchOptimizer(self._tmp_graph_def).do_transformation()
 
         self._tmp_graph_def = RemoveTrainingNodesOptimizer(
@@ -125,11 +124,6 @@ class PreOptimization():
         self._tmp_graph_def = ConvertLeakyReluOptimizer(
             self._tmp_graph_def).do_transformation()
 
-        #TODO we need to remove below optimizer once the TF enabled the single
-        # matmul op quantization
-        self._tmp_graph_def = InjectDummyBiasAddOptimizer(
-            self._tmp_graph_def).do_transformation()
-
         self._tmp_graph_def = ConvertAddToBiasAddOptimizer(
             self._tmp_graph_def).do_transformation()
 
@@ -139,9 +133,23 @@ class PreOptimization():
         self._tmp_graph_def = FuseConvWithMathOptimizer(
             self._tmp_graph_def).do_transformation()
 
+        self._tmp_graph_def = ExpandDimsOptimizer(
+            self._tmp_graph_def).do_transformation()
+     
+        #TODO we need to remove below optimizer once the TF enabled the single
+        # matmul op quantization
+        self._tmp_graph_def = InjectDummyBiasAddOptimizer(
+            self._tmp_graph_def).do_transformation()
+            
         self._tmp_graph_def = FuseBiasAddAndAddOptimizer(
             self._tmp_graph_def).do_transformation()
 
+        self._tmp_graph_def = MoveSqueezeAfterReluOptimizer(
+            self._tmp_graph_def).do_transformation()
+
+        self._tmp_graph_def = ConvertNanToRandom(
+            self._tmp_graph_def).do_transformation()
+
         self._excluded_node_names.extend(excluded_node_names)
         self._tmp_graph_def.library.CopyFrom(self.model.graph_def.library)
 
