@@ -81,16 +81,20 @@ def _valid_accuracy_field(key, scope, error):
         'absolute' in scope['accuracy_criterion'])
 
 def _valid_prune_epoch(key, scope, error):
-    if "start_epoch" in scope and "end_epoch" in scope:
-        assert scope["start_epoch"] <= scope["end_epoch"]
+    if "start_epoch" in scope[key] and "end_epoch" in scope[key]:
+        assert scope[key]["start_epoch"] <= scope[key]["end_epoch"]
 
 def _valid_prune_sparsity(key, scope, error):
-    if "initial_sparsity" in scope and "target_sparsity" in scope:
-        assert scope["initial_sparsity"] <= scope["target_sparsity"]
-    elif "initial_sparsity" in scope:
-        assert scope["initial_sparsity"] >= 0
-    else:
-        assert scope["target_sparsity"] < 1
+    if "initial_sparsity" in scope[key] and "target_sparsity" in scope[key]:
+        assert scope[key]["initial_sparsity"] <= scope[key]["target_sparsity"]
+    elif "initial_sparsity" in scope[key]:
+        assert scope[key]["initial_sparsity"] >= 0
+    elif "target_sparsity" in scope[key]:
+        assert scope[key]["target_sparsity"] < 1
+
+def _valid_multi_objective(key, scope, error):
+    if 'weight' in scope and scope['weight'] is not None:
+        assert len(scope['objective']) == len(scope['weight'])
 
 # used for '123.68 116.78 103.94' style to float list
 def input_to_list_float(data):
@@ -173,8 +177,8 @@ ops_schema = Schema({
             lambda s: all(i in ['per_channel', 'per_tensor'] for i in s)),
         Optional('scheme', default=None): And(
             list,
-            # asym_float and placeholder is only for PyTorch framework
-            lambda s: all(i in ['asym', 'sym', 'asym_float', 'placeholder'] for i in s)),
+            # asym_float are only for PyTorch framework
+            lambda s: all(i in ['asym', 'sym', 'asym_float'] for i in s)),
         Optional('dtype', default=None): And(
             list,
             lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16'] for i in s)),
@@ -196,9 +200,14 @@ ops_schema = Schema({
         Optional('dtype', default=None): And(
             list,
             lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16'] for i in s)),
+        # compute_dtypeis only for PyTorch framework
+        Optional('compute_dtype', default=['uint8']): And(
+            list,
+            lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16', 'None'] for i in s)),
+        # placeholder are only for PyTorch framework
         Optional('algorithm', default=None): And(
             list,
-            lambda s: all(i in ['minmax', 'kl'] for i in s))
+            lambda s: all(i in ['minmax', 'kl', 'placeholder'] for i in s))
     }
 })
 
@@ -331,9 +340,17 @@ transform_schema = Schema({
         Optional('random_crop'): bool,
         Optional('slice_crop'): bool,
         Optional('resize_side'): And(int, lambda s: s > 0),
+        Optional('resize_method', default='bilinear'): \
+            And(str, lambda s: s in ['bilinear', 'lanczos3', 'lanczos5',
+                                     'bicubic', 'gaussian', 'nearest',
+                                     'area', 'mitchellcubic']),
         Optional('random_flip_left_right'): bool,
+        Optional('data_format', default='channels_last'): \
+            And(str, lambda s: s in ['channels_first', 'channels_last']),
+        Optional('subpixels', default='RGB'): \
+            And(str, lambda s: s in ['BGR', 'RGB']),
         Optional('mean_value'): And(Or(str, list), Use(input_to_list_float)),
-        Optional('scale'): float
+        Optional('scale'): float,
     },
     Optional('ResizeWithAspectRatio'):{
         'height': And(int, lambda s: s > 0),
@@ -499,12 +516,30 @@ optimizer_schema = Schema({
         Optional('momentum'): float,
         Optional('nesterov'): bool,
         Optional('weight_decay'): float
+    },
+    Optional('AdamW'): {
+        'weight_decay': float,
+        Optional('learning_rate', default=0.001): float,
+        Optional('beta_1', default=0.9): float,
+        Optional('beta_2', default=0.999): float,
+        Optional('epsilon', default=1e-07): float,
+        Optional('amsgrad', default=False):
+            And(bool, lambda s: s in [True, False])
     }
 })
 
 criterion_schema = Schema({
     Optional('CrossEntropyLoss'): {
-        Optional('reduction', default='mean'): And(str, lambda s: s in ['none', 'sum', 'mean'])
+        Optional('reduction', default='mean'): \
+            And(str, lambda s: s in ['none', 'sum', 'mean', 'auto', 'sum_over_batch_size']),
+        Optional('from_logits', default=False):
+            And(bool, lambda s: s in [True, False]),
+    },
+    Optional('SparseCategoricalCrossentropy'): {
+        Optional('reduction', default='mean'): \
+            And(str, lambda s: s in ['none', 'sum', 'mean', 'auto', 'sum_over_batch_size']),
+        Optional('from_logits', default=False):
+            And(bool, lambda s: s in [True, False]),
     },
     Optional('KnowledgeDistillationLoss'): {
         Optional('temperature'): And(float, lambda s: s > 0),
@@ -522,6 +557,10 @@ train_schema = Schema({
     Optional('end_epoch'): int,
     Optional('iteration'): int,
     Optional('frequency'): int,
+    Optional('execution_mode', default='eager'): And(str, lambda s: s in ['eager', 'graph']),
+    Optional('postprocess'): {
+        Optional('transform'): postprocess_schema
+    },
     # TODO reserve for multinode training support
     Optional('hostfile'): str
 })
@@ -536,6 +575,7 @@ weight_compression_schema = Schema({
 })
 
 approach_schema = Schema({
+    Hook('weight_compression', handler=_valid_prune_sparsity): object,
     Optional('weight_compression'): weight_compression_schema,
 })
 
@@ -552,7 +592,7 @@ COCOmAP_input_order_schema = Schema({
 schema = Schema({
     'model': {
         'name': str,
-        'framework': And(str, lambda s: s in FRAMEWORKS),
+        'framework': And(str, lambda s: s in list(FRAMEWORKS.keys()) + ['NA']),
         Optional('inputs', default=[]): And(Or(str, list), Use(input_to_list)),
         Optional('outputs', default=[]): And(Or(str, list), Use(input_to_list)),
     },
@@ -580,6 +620,7 @@ schema = Schema({
         Optional('advance', default=None): {
             Optional('bias_correction'): And(str, lambda s: s in ['weight_empirical']),
         },
+        Optional('dtype', default='int8'): And(str, Or('int8', 'bf16')),
         Optional('calibration', default={'sampling_size': [100]}): {
             Optional('sampling_size', default=[100]): And(Or(str, int, list), Use(input_to_list)),
             Optional('dataloader', default=None): dataloader_schema
@@ -604,10 +645,11 @@ schema = Schema({
                     Or(str, list),
                     Use(input_to_list),
                     lambda s: all(i in ['per_channel', 'per_tensor'] for i in s)),
+                # asym_float are only for PyTorch framework
                 Optional('scheme', default=None): And(
                     Or(str, list),
                     Use(input_to_list),
-                    lambda s: all(i in ['asym', 'sym'] for i in s)),
+                    lambda s: all(i in ['asym', 'sym', 'asym_float'] for i in s)),
                 Optional('dtype', default=None): And(
                     Or(str, list),
                     Use(input_to_list),
@@ -635,10 +677,16 @@ schema = Schema({
                     Or(str, list),
                     Use(input_to_list),
                     lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16'] for i in s)),
+                # compute_dtypeis only for PyTorch framework
+                Optional('compute_dtype', default=['uint8']): And(
+                    Or(str, list),
+                    Use(input_to_list),
+                    lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16', 'None'] for i in s)),
+                # placeholder are only for PyTorch framework
                 Optional('algorithm', default=None): And(
                     Or(str, list),
                     Use(input_to_list),
-                    lambda s: all(i in ['minmax', 'kl'] for i in s)),
+                    lambda s: all(i in ['minmax', 'kl', 'placeholder'] for i in s)),
             }
         },
         Optional('op_wise', default=None): {
@@ -653,7 +701,7 @@ schema = Schema({
     Optional('tuning', default={
         'strategy': {'name': 'basic'},
         'accuracy_criterion': {'relative': 0.01, 'higher_is_better': True},
-        'objective': 'performance',
+        'multi_objective': {'objective': ['performance']},
         'exit_policy': {'timeout': 0, 'max_trials': 100, 'performance_only': False},
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): {
@@ -670,7 +718,12 @@ schema = Schema({
             Optional('absolute'): And(Or(str, int, float), Use(percent_to_float)),
             Optional('higher_is_better', default=True): bool,
         },
-        Optional('objective', default='performance'): And(str, lambda s: s in OBJECTIVES),
+        Hook('multi_objective', handler=_valid_multi_objective): object,
+        Optional('multi_objective', default={'objective': ['performance']}): {
+            Optional('objective', default=['performance']): And(
+                Or(str, list), Use(input_to_list), lambda s: all(i in OBJECTIVES for i in s)),
+            Optional('weight', default=None): And(Or(str, list), Use(input_to_list_float)),
+        },
         Optional('exit_policy', default={'timeout': 0,
                                          'max_trials': 100,
                                          'performance_only': False}): {
@@ -754,6 +807,7 @@ schema = Schema({
         },
     },
     Optional('pruning'): {
+        Hook('train', handler=_valid_prune_epoch): object,
         Optional("train"): train_schema,
         Optional("approach"): approach_schema
     },
@@ -775,7 +829,7 @@ quantization_default_schema = Schema({
     Optional('device', default='cpu'): str,
 
     Optional('quantization', default={'approach': 'post_training_static_quant', \
-                                      'calibration': {'sampling_size': [100]}, \
+                                      'calibration': {'sampling_size': [100]},
                                       'recipes': {'scale_propagation_max_pooling': True,
                                                       'scale_propagation_concat': True,
                                                       'first_conv_or_matmul_quantization': True},
@@ -785,12 +839,12 @@ quantization_default_schema = Schema({
     Optional('tuning', default={
         'strategy': {'name': 'basic'},
         'accuracy_criterion': {'relative': 0.01, 'higher_is_better': True},
-        'objective': 'performance',
+        'multi_objective': {'objective': ['performance']},
         'exit_policy': {'timeout': 0, 'max_trials': 100, 'performance_only': False},
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): dict,
 
-    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}  }): dict
+    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}}): dict
 })
 
 pruning_default_schema = Schema({
@@ -806,9 +860,11 @@ pruning_default_schema = Schema({
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): dict,
 
-    Optional('pruning', default={'approach': {'weight_compression':{'initial_sparsity': 0, \
+    Optional('pruning', default={'approach': {'weight_compression':{'initial_sparsity': 0.0, \
                                             'target_sparsity': 0.97, 'start_epoch': 0, \
-                                            'end_epoch': 4}}}): dict
+                                            'end_epoch': 4}}}): dict,
+
+    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}}): dict
 })
 
 graph_optimization_default_schema = Schema({
@@ -820,8 +876,8 @@ graph_optimization_default_schema = Schema({
 
     Optional('device', default='cpu'): str,
 
-    Optional('quantization', default={'approach': 'post_training_static_quant', \
-                                    'calibration': {'sampling_size': [100]}, \
+    Optional('quantization', default={'approach': 'post_training_static_quant', 
+                                    'calibration': {'sampling_size': [100]},
                                     'recipes': {'scale_propagation_max_pooling': True,
                                                     'scale_propagation_concat': True,
                                                     'first_conv_or_matmul_quantization': True},
@@ -831,14 +887,14 @@ graph_optimization_default_schema = Schema({
     Optional('tuning', default={
         'strategy': {'name': 'basic'},
         'accuracy_criterion': {'relative': 0.01, 'higher_is_better': True},
-        'objective': 'performance',
+        'multi_objective': {'objective': ['performance']},
         'exit_policy': {'timeout': 0, 'max_trials': 100, 'performance_only': False},
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): dict,
 
-    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}  }): dict,
+    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}}): dict,
 
-    Optional('graph_optimization', default={'precisions': ['bf16, fp32']}): dict
+    Optional('graph_optimization', default={'precisions': ['bf16, fp32']}): dict 
 })
 
 benchmark_default_schema = Schema({
@@ -850,8 +906,8 @@ benchmark_default_schema = Schema({
 
     Optional('device', default='cpu'): str,
 
-    Optional('quantization', default={'approach': 'post_training_static_quant', \
-                                    'calibration': {'sampling_size': [100]}, \
+    Optional('quantization', default={'approach': 'post_training_static_quant', 
+                                    'calibration': {'sampling_size': [100]},
                                     'recipes': {'scale_propagation_max_pooling': True,
                                                     'scale_propagation_concat': True,
                                                     'first_conv_or_matmul_quantization': True},
@@ -861,12 +917,12 @@ benchmark_default_schema = Schema({
     Optional('tuning', default={
         'strategy': {'name': 'basic'},
         'accuracy_criterion': {'relative': 0.01, 'higher_is_better': True},
-        'objective': 'performance',
+        'multi_objective': {'objective': ['performance']},
         'exit_policy': {'timeout': 0, 'max_trials': 100, 'performance_only': False},
         'random_seed': 1978, 'tensorboard': False,
         'workspace': {'path': default_workspace}}): dict,
 
-    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}  }): dict
+    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}}): dict
 })
 
 distillation_default_schema = Schema({
@@ -883,15 +939,16 @@ distillation_default_schema = Schema({
         'workspace': {'path': default_workspace}}): dict,
 
     Optional('distillation', default={
-        'train': {'start_epoch': 0, 'end_epoch': 10, \
-                  'iteration': 1000, 'frequency': 1, \
-                  'optimizer': {'SGD': {'learning_rate': 0.001}}, \
-                  'criterion': {'KnowledgeDistillationLoss': \
-                                 {'temperature': 1.0, \
-                                  'loss_types': ['CE', 'KL'], \
+        'train': {'start_epoch': 0, 'end_epoch': 10, 
+                  'iteration': 1000, 'frequency': 1, 
+                  'optimizer': {'SGD': {'learning_rate': 0.001}}, 
+                  'criterion': {'KnowledgeDistillationLoss': 
+                                 {'temperature': 1.0, 
+                                  'loss_types': ['CE', 'KL'], 
                                   'loss_weights': [0.5, 0.5]}}}}): dict,
 
-    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}  }): dict
+    Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}}):dict
+ 
 })
 
 class Conf(object):
@@ -939,17 +996,56 @@ class Conf(object):
                 "The yaml file format is not correct. Please refer to document."
             )
 
+    def _convert_cfg(self, src, dst):
+        """Helper function to merge user defined dict into default dict.
+
+           If the key in src doesn't exist in dst, then add this key and value
+           pair to dst.
+           If the key in src is in dst, then override the value in dst with the
+           value in src.
+
+        Args:
+            src (dict): The source dict merged from
+            dst (dict): The source dict merged to
+
+        Returns:
+            dict: The merged dict from src to dst
+        """
+        for key in src:
+            if key in dst:
+                if isinstance(dst[key], dict) and isinstance(src[key], dict):
+                    if key in ['accuracy_criterion', 'metric', 'dataset', 
+                        'criterion', 'optimizer']:
+                        # accuracy_criterion can only have one of absolute and relative
+                        # others can only have one item
+                        inter_key = src[key].keys() & dst[key].keys() - 'higher_is_better'
+                        if len(inter_key) == 0:
+                            dst[key] = {}
+                    self._convert_cfg(src[key], dst[key])
+                elif dst[key] == src[key]:
+                    pass  # same leaf value
+                else:
+                    dst[key] = src[key]
+            elif isinstance(src[key], dict):
+                dst[key] = DotDict(self._convert_cfg(src[key], {}))
+            else:
+                dst[key] = src[key]
+        return dst
+
 class Quantization_Conf(Conf):
     """config parser.
 
     Args:
-        cfg_fname (string): The path to the configuration file.
+        cfg: The path to the configuration file or DotDict object or None.
 
     """
 
-    def __init__(self, cfg_fname):
-        if cfg_fname:
-            self.usr_cfg = DotDict(self._read_cfg(cfg_fname))
+    def __init__(self, cfg=None):
+        if isinstance(cfg, str):
+            self.usr_cfg = DotDict(self._read_cfg(cfg))
+        elif isinstance(cfg, DotDict):
+            self.usr_cfg = DotDict(schema.validate(self._convert_cfg(
+                cfg, quantization_default_schema.validate(dict()))))
         else:
             self.usr_cfg = DotDict(quantization_default_schema.validate(dict()))
         self._model_wise_tune_space = None
@@ -1061,7 +1157,7 @@ class Quantization_Conf(Conf):
         self._opwise_tune_space = opwise
         return self._opwise_tune_space
 
-    def expand_tune_cfgs(self, tune_space):
+    def expand_tune_cfgs(self, tune_space, framework):
         """generate all possible tuning combinations for each op or model wise tuning.
 
         Args:
@@ -1080,7 +1176,7 @@ class Quantization_Conf(Conf):
             cfg = DotDict(cfg)
             dtype = cfg.activation.dtype
 
-            if dtype not in quant_dtype:
+            if dtype not in quant_dtype and "pytorch" not in framework:
                 cfg.activation.clear()
                 cfg.activation.dtype = dtype
 
@@ -1092,11 +1188,14 @@ class Quantization_Conf(Conf):
                 if (cfg.weight.dtype != cfg.activation.dtype and
                     cfg.weight.dtype not in quant_dtype and
                     cfg.activation.dtype not in quant_dtype) or \
-                    (cfg.weight.dtype != cfg.activation.dtype and
-                     cfg.weight.dtype in quant_dtype and
-                     cfg.activation.dtype not in quant_dtype) or \
-                    (cfg.weight.dtype != cfg.activation.dtype and
-                     cfg.weight.dtype not in quant_dtype and cfg.activation.dtype in quant_dtype):
+                   (cfg.weight.dtype != cfg.activation.dtype and
+                    cfg.weight.dtype in quant_dtype and
+                    cfg.activation.dtype not in quant_dtype and
+                    ("pytorch" not in framework or
+                     len(tune_space['activation']['dtype']) > 1)) or \
+                   (cfg.weight.dtype != cfg.activation.dtype and
+                    cfg.weight.dtype not in quant_dtype and
+                    cfg.activation.dtype in quant_dtype):
                     continue
 
             valid_cfgs.append(cfg)
@@ -1133,13 +1232,16 @@ class Pruning_Conf(Conf):
     """config parser.
 
     Args:
-        cfg_fname (string): The path to the configuration file.
+        cfg: The path to the configuration file or DotDict object or None.
 
     """
 
-    def __init__(self, cfg_fname):
-        if cfg_fname:
-            self.usr_cfg = DotDict(self._read_cfg(cfg_fname))
+    def __init__(self, cfg=None):
+        if isinstance(cfg, str):
+            self.usr_cfg = DotDict(self._read_cfg(cfg))
+        elif isinstance(cfg, DotDict):
+            self.usr_cfg = DotDict(schema.validate(self._convert_cfg(
+                cfg, pruning_default_schema.validate(dict()))))
         else:
             self.usr_cfg = DotDict(pruning_default_schema.validate(dict()))
 
@@ -1147,13 +1249,16 @@ class Graph_Optimization_Conf(Quantization_Conf):
     """config parser.
 
     Args:
-        cfg_fname (string): The path to the configuration file.
+        cfg: The path to the configuration file or DotDict object or None.
 
     """
 
-    def __init__(self, cfg_fname):
-        if cfg_fname:
-            self.usr_cfg = DotDict(self._read_cfg(cfg_fname))
+    def __init__(self, cfg=None):
+        if isinstance(cfg, str):
+            self.usr_cfg = DotDict(self._read_cfg(cfg))
+        elif isinstance(cfg, DotDict):
+            self.usr_cfg = DotDict(schema.validate(self._convert_cfg(
+                cfg, graph_optimization_default_schema.validate(dict()))))
         else:
             self.usr_cfg = DotDict(graph_optimization_default_schema.validate(dict()))
 
@@ -1161,13 +1266,16 @@ class Benchmark_Conf(Conf):
     """config parser.
 
     Args:
-        cfg_fname (string): The path to the configuration file.
+        cfg: The path to the configuration file or DotDict object or None.
 
     """
 
-    def __init__(self, cfg_fname):
-        if cfg_fname:
-            self.usr_cfg = DotDict(self._read_cfg(cfg_fname))
+    def __init__(self, cfg=None):
+        if isinstance(cfg, str):
+            self.usr_cfg = DotDict(self._read_cfg(cfg))
+        elif isinstance(cfg, DotDict):
+            self.usr_cfg = DotDict(schema.validate(self._convert_cfg(
+                cfg, benchmark_default_schema.validate(dict()))))
         else:
             self.usr_cfg = DotDict(benchmark_default_schema.validate(dict()))
 
@@ -1175,12 +1283,26 @@ class Distillation_Conf(Conf):
     """config parser.
 
     Args:
-        cfg_fname (string): The path to the configuration file.
+        cfg: The path to the configuration file or DotDict object or None.
 
     """
 
-    def __init__(self, cfg_fname):
-        if cfg_fname:
-            self.usr_cfg = DotDict(self._read_cfg(cfg_fname))
+    def __init__(self, cfg=None):
+        if isinstance(cfg, str):
+            self.usr_cfg = DotDict(self._read_cfg(cfg))
+        elif isinstance(cfg, DotDict):
+            self.usr_cfg = DotDict(schema.validate(self._convert_cfg(
+                cfg, distillation_default_schema.validate(dict()))))
         else:
             self.usr_cfg = DotDict(distillation_default_schema.validate(dict()))
+
+class DefaultConf(DotDict):
+    def __getitem__(self, key):
+        if key not in self:
+            self[key] = DefaultConf({})
+        value = self.get(key, None)
+        return value
+
+    __getattr__ = __getitem__
+
+conf = DefaultConf({})
