@@ -93,7 +93,7 @@ class BasicTuneStrategy(TuneStrategy):
         # Model wise tuning
         op_cfgs = {}
         best_cfg = None
-        best_acc = 0
+        best_acc = float('-inf') if self.higher_is_better else float('inf')
 
         logger.debug("Start basic strategy by model-wise tuning.")
         for i, iterations in enumerate(self.calib_iter):
@@ -112,7 +112,8 @@ class BasicTuneStrategy(TuneStrategy):
 
                 yield op_cfgs
                 acc, _ = self.last_tune_result
-                if acc >= best_acc:
+                if (self.higher_is_better and acc >= best_acc) or \
+                    (not self.higher_is_better and acc <= best_acc):
                     best_acc = acc
                     best_cfg = copy.deepcopy(op_cfgs)
 
@@ -132,13 +133,14 @@ class BasicTuneStrategy(TuneStrategy):
                 for op, configs in reversed(self.opwise_tune_cfgs.items()):
                     op_cfgs = copy.deepcopy(best_cfg)
                     for cfg in configs:
-                        if fallback_dtype == cfg['activation']['dtype']:
+                        if ('weight' in cfg and fallback_dtype == cfg['weight']['dtype']) \
+                           or ('weight' not in cfg
+                               and fallback_dtype == cfg['activation']['dtype']):
+                            op_cfgs['op'][op]['weight'].clear()
+                            op_cfgs['op'][op]['weight']['dtype'] = fallback_dtype
+                            assert cfg['activation']['dtype'] == fallback_dtype
                             op_cfgs['op'][op]['activation'].clear()
                             op_cfgs['op'][op]['activation']['dtype'] = fallback_dtype
-                            if 'weight' in cfg:
-                                assert cfg['weight']['dtype'] == fallback_dtype
-                                op_cfgs['op'][op]['weight'].clear()
-                                op_cfgs['op'][op]['weight']['dtype'] = fallback_dtype
                     yield op_cfgs
                     acc, _ = self.last_tune_result
                     ops_acc[op] = acc
@@ -146,20 +148,22 @@ class BasicTuneStrategy(TuneStrategy):
                 op_cfgs = copy.deepcopy(best_cfg)
                 if ops_acc is not None:
                     ordered_ops = sorted(ops_acc.keys(), key=lambda key: ops_acc[key],
-                                         reverse=True)
+                                         reverse=self.higher_is_better)
                     for op in ordered_ops:
                         old_cfg = copy.deepcopy(op_cfgs['op'][op])
                         for cfg in self.opwise_tune_cfgs[op]:
-                            if fallback_dtype == cfg['activation']['dtype']:
+                            if ('weight' in cfg and fallback_dtype == cfg['weight']['dtype']) \
+                               or ('weight' not in cfg
+                                   and fallback_dtype == cfg['activation']['dtype']):
+                                op_cfgs['op'][op]['weight'].clear()
+                                op_cfgs['op'][op]['weight']['dtype'] = fallback_dtype
+                                assert cfg['activation']['dtype'] == fallback_dtype
                                 op_cfgs['op'][op]['activation'].clear()
                                 op_cfgs['op'][op]['activation']['dtype'] = fallback_dtype
-                                if 'weight' in cfg:
-                                    assert cfg['weight']['dtype'] == fallback_dtype
-                                    op_cfgs['op'][op]['weight'].clear()
-                                    op_cfgs['op'][op]['weight']['dtype'] = fallback_dtype
                         yield op_cfgs
                         acc, _ = self.last_tune_result
-                        if acc <= best_acc:
+                        if (self.higher_is_better and acc <= best_acc) or \
+                            (not self.higher_is_better and acc >= best_acc):
                             op_cfgs['op'][op] = copy.deepcopy(old_cfg)
                         else:
                             best_acc = acc
@@ -167,12 +171,14 @@ class BasicTuneStrategy(TuneStrategy):
                     op_cfgs = copy.deepcopy(best_cfg)
                     for op in ordered_ops:
                         for cfg in self.opwise_tune_cfgs[op]:
-                            if fallback_dtype == cfg['activation']['dtype']:
+                            if ('weight' in cfg and fallback_dtype == cfg['weight']['dtype']) \
+                               or ('weight' not in cfg
+                                   and fallback_dtype == cfg['activation']['dtype']):
+                                op_cfgs['op'][op]['weight'].clear()
+                                op_cfgs['op'][op]['weight']['dtype'] = fallback_dtype
+                                assert cfg['activation']['dtype'] == fallback_dtype
                                 op_cfgs['op'][op]['activation'].clear()
                                 op_cfgs['op'][op]['activation']['dtype'] = fallback_dtype
-                                if 'weight' in op_cfgs['op'][op]:
-                                    op_cfgs['op'][op]['weight'].clear()
-                                    op_cfgs['op'][op]['weight']['dtype'] = fallback_dtype
                         yield op_cfgs
         else:
             logger.debug(self.opwise_tune_cfgs)
