@@ -24,8 +24,8 @@ from collections import OrderedDict
 from pathlib import Path
 import yaml
 import numpy as np
+from ..objective import MultiObjective
 from ..adaptor import FRAMEWORKS
-from ..objective import OBJECTIVES
 from ..utils.utility import fault_tolerant_file, equal_dicts, GLOBAL_STATE, MODE
 from ..utils.create_obj_from_config import create_eval_func, create_train_func
 from ..utils import logger
@@ -164,7 +164,8 @@ class TuneStrategy(object):
                     {"default_qconfig": self.cfg['quantization']['op_wise']['default_qconfig']})
         if framework == 'engine':
             framework_specific_info.update(
-                 {'workspace_path': self.cfg.tuning.workspace.path})
+                 {'workspace_path': self.cfg.tuning.workspace.path,
+                  'q_dtype': self.cfg.quantization.dtype})
 
         self.adaptor = FRAMEWORKS[framework](framework_specific_info)
         self.framework = framework
@@ -184,9 +185,13 @@ class TuneStrategy(object):
         self.best_tune_result = None
         self.best_qmodel = None
 
-        objective = self.cfg.tuning.objective.lower()
-        self.objective = OBJECTIVES[objective](self.cfg.tuning.accuracy_criterion)
-
+        self.higher_is_better = bool(self.cfg.tuning.accuracy_criterion.higher_is_better)
+        self.use_multi_objective = len(self.cfg.tuning.multi_objective.objective) > 1
+        objectives = [i.lower() for i in self.cfg.tuning.multi_objective.objective]
+        self.tune_result_record = []
+        self.multi_objective = MultiObjective(objectives, 
+                                              self.cfg.tuning.accuracy_criterion,
+                                              self.cfg.tuning.multi_objective.weight)
         self.capability = self.adaptor.query_fw_capability(model)
         self.graph_optimization_mode = bool('graph_optimization' in self.cfg)
 
@@ -194,10 +199,10 @@ class TuneStrategy(object):
         self.opwise_tune_space = conf.opwise_tune_space(self.capability['opwise'])
         self.model_wise_tune_cfgs = OrderedDict()
         for optype, optype_cfgs in self.modelwise_tune_space.items():
-            self.model_wise_tune_cfgs[optype] = conf.expand_tune_cfgs(optype_cfgs)
+            self.model_wise_tune_cfgs[optype] = conf.expand_tune_cfgs(optype_cfgs, self.framework)
         self.opwise_tune_cfgs = OrderedDict()
         for key in self.opwise_tune_space:
-            expanded_cfg = conf.expand_tune_cfgs(self.opwise_tune_space[key])
+            expanded_cfg = conf.expand_tune_cfgs(self.opwise_tune_space[key], self.framework)
             if expanded_cfg:
                 self.opwise_tune_cfgs[key] = expanded_cfg
 
@@ -213,7 +218,9 @@ class TuneStrategy(object):
         for optype in self.model_wise_tune_cfgs.keys():
             self.model_wise_quant_cfgs[optype] = []
             for cfg in self.model_wise_tune_cfgs[optype]:
-                if cfg['activation']['dtype'] not in fallback_precision_list:
+                if ('weight' in cfg and cfg['weight']['dtype'] not in fallback_precision_list) \
+                   or ('weight' not in cfg
+                       and cfg['activation']['dtype'] not in fallback_precision_list):
                     self.model_wise_quant_cfgs[optype].append(cfg)
         self.combined_model_wise_quant_cfgs = conf._combine_optype_quant_cfgs(
                                          self.model_wise_quant_cfgs)
@@ -229,7 +236,10 @@ class TuneStrategy(object):
                     if cfg['activation']['dtype'] in self.cfg.graph_optimization.precisions:
                         new_list.append(cfg)
                 else:
-                    if cfg['activation']['dtype'] not in fallback_precision_list:
+                    if ('weight' in cfg
+                        and cfg['weight']['dtype'] not in fallback_precision_list) \
+                       or ('weight' not in cfg
+                           and cfg['activation']['dtype'] not in fallback_precision_list):
                         new_list.append(cfg)
             self.opwise_quant_cfgs[key] = new_list
 
@@ -313,9 +323,10 @@ class TuneStrategy(object):
             self.baseline = self._evaluate(self.model)
             # record the FP32 baseline
             self._add_tuning_history()
-        baseline_msg = '[Accuracy: {:.4f}, {}: {:.4f}]'.format(self.baseline[0],
-                                str(self.objective.measurer).capitalize(), \
-                                self.baseline[1]) if self.baseline else 'n/a'
+        baseline_msg = '[Accuracy: {:.4f}'.format(self.baseline[0]) + \
+            ''.join([', {}: {:.4f}'.format(x,y) for x,y in zip( \
+            self.multi_objective.representation, self.baseline[1]) if x != 'Accuracy']) + ']' \
+            if self.baseline else 'n/a'
         logger.info("FP32 baseline is: {}".format(baseline_msg))
 
         trials_count = 0
@@ -350,7 +361,19 @@ class TuneStrategy(object):
             self._add_tuning_history(saved_tune_cfg,
                                     saved_last_tune_result,
                                     q_config=self.q_model.q_config)
+            self.tune_result_record.append(copy.deepcopy(self.last_tune_result))
             if need_stop:
+                if self.use_multi_objective and len(self.tune_result_record) > 1 and \
+                    self.best_tune_result is not None:
+                    best_trail, best_result = self.multi_objective.best_result(
+                                                            self.tune_result_record,
+                                                            copy.deepcopy(self.baseline))
+                    if best_result != self.best_tune_result:
+                        from neural_compressor.utils.utility import recover
+                        self.best_qmodel = recover(self.model.model, 
+                            os.path.join(self.cfg.tuning.workspace.path, 'history.snapshot'),
+                            best_trail)
+                        self.best_tune_result = best_result
                 break
 
     def deploy_config(self):
@@ -433,7 +456,7 @@ class TuneStrategy(object):
                 # Pytorch can insert observer to model in this hook.
                 # Tensorflow don't support this mode for now
                 model = self.adaptor._pre_eval_hook(model)
-            val = self.objective.evaluate(self.eval_func, model.model)
+            val = self.multi_objective.evaluate(self.eval_func, model.model)
             if self.cfg.tuning.tensorboard:
                 # post_eval_hook to deal the tensor
                 self.adaptor._post_eval_hook(model, accuracy=val[0])
@@ -475,7 +498,7 @@ class TuneStrategy(object):
                                 raise AttributeError("The evaluation dataloader's iteration is"
                                                      "different between processes, please reset "
                                                      "dataloader's batch_size.")
-            val = self.objective.evaluate(eval_func, model)
+            val = self.multi_objective.evaluate(eval_func, model)
         assert np.isscalar(val[0]), \
             "The eval_func should return a scalar, but not {}!".format(str(type(val[0])))
         return val
@@ -504,9 +527,8 @@ class TuneStrategy(object):
             bool: True if need stop, otherwise False
         """
         need_stop = False
-
         if self.cfg.tuning.exit_policy.performance_only or \
-            self.objective.compare(self.best_tune_result, self.baseline):
+            self.multi_objective.compare(self.best_tune_result, self.baseline):
             del self.best_tune_result
             del self.best_qmodel
             self.best_tune_result = self.last_tune_result
@@ -514,14 +536,18 @@ class TuneStrategy(object):
         else:
             del self.last_qmodel
 
-        last_tune_msg = '[Accuracy (int8|fp32): {:.4f}|{:.4f}, {} (int8|fp32): {:.4f}|{:.4f}]'.format( \
-                                self.last_tune_result[0], self.baseline[0], \
-                                str(self.objective.measurer).capitalize(), \
-                                self.last_tune_result[1], self.baseline[1]) \
-                                if self.last_tune_result else 'n/a'
-        best_tune_msg = '[Accuracy: {:.4f}, {}: {:.4f}]'.format(self.best_tune_result[0], \
-                                str(self.objective.measurer).capitalize(), \
-                                self.best_tune_result[1]) if self.best_tune_result else 'n/a'
+        last_tune_msg = '[Accuracy ({}|fp32): {:.4f}|{:.4f}'.format( \
+            self.cfg.quantization.dtype, self.last_tune_result[0], self.baseline[0]) + \
+            ''.join([', {} ({}|fp32): {:.4f}|{:.4f}'.format(x,self.cfg.quantization.dtype,y,z) \
+            for x,y,z in zip(self.multi_objective.representation, \
+            self.last_tune_result[1], self.baseline[1]) if x != 'Accuracy']) + ']' \
+            if self.last_tune_result else 'n/a'
+
+        best_tune_msg = '[Accuracy: {:.4f}'.format(self.best_tune_result[0]) + \
+            ''.join([', {}: {:.4f}'.format(x,y) for x,y in zip( \
+            self.multi_objective.representation, self.best_tune_result[1]) if x != 'Accuracy']) \
+            + ']' if self.best_tune_result else 'n/a'
+ 
         logger.info("Tune {} result is: {}, Best tune result is: {}".format(trials_count,
                                                                             last_tune_msg,
                                                                             best_tune_msg))
