@@ -16,6 +16,7 @@ from neural_compressor.experimental import Quantization, common
 from neural_compressor.experimental import Benchmark, common
 from neural_compressor import options
 from neural_compressor.adaptor.pytorch import get_torch_version, PyTorchVersionMode
+from neural_compressor import conf
 
 def build_static_yaml():
     fake_yaml = """
@@ -126,7 +127,8 @@ def build_gather_yaml():
         evaluation:
           accuracy:
             metric:
-              Accuracy: {}
+              MSE:
+                compare_label: False
             dataloader:
               dataset:
                 dummy_v2:
@@ -255,8 +257,19 @@ def build_matmul_model():
     A = helper.make_tensor_value_info('A', TensorProto.FLOAT, [1, 1, 5, 5])
     B = helper.make_tensor_value_info('B', TensorProto.FLOAT, [1, 1, 5, 1])
     C = helper.make_tensor_value_info('C', TensorProto.FLOAT, [1, 1, 5, 1])
+    D = helper.make_tensor_value_info('D', TensorProto.FLOAT, [1, 1, 5, 1])
+    H = helper.make_tensor_value_info('H', TensorProto.FLOAT, [1, 1, 5, 1])
+ 
     matmul_node = onnx.helper.make_node('MatMul', ['A', 'B'], ['C'], name='Matmul')
-    graph = helper.make_graph([matmul_node], 'test_graph_1', [A, B], [C])
+    e_value = np.random.randint(2, size=(5)).astype(np.float32)
+    E_init = helper.make_tensor('E', TensorProto.FLOAT, [1, 1, 5, 1], e_value.reshape(5).tolist())
+    add = onnx.helper.make_node('Add', ['C', 'E'], ['D'], name='add')
+ 
+    f_value = np.random.randint(2, size=(5)).astype(np.float32)
+    F_init = helper.make_tensor('F', TensorProto.FLOAT, [1, 1, 5, 1], e_value.reshape(5).tolist())
+    add2 = onnx.helper.make_node('Add', ['D', 'F'], ['H'], name='add2')
+ 
+    graph = helper.make_graph([matmul_node, add, add2], 'test_graph_1', [A, B], [H], [E_init, F_init])
     model = helper.make_model(graph)
     model = helper.make_model(graph, **{'opset_imports': [helper.make_opsetid('', 13)]})
     return model
@@ -406,8 +419,8 @@ class TestAdaptorONNXRT(unittest.TestCase):
         quantizer = Quantization("static.yaml")
         quantizer.calib_dataloader = self.cv_dataloader
         quantizer.eval_dataloader = self.cv_dataloader
-        quantizer.model = common.Model(self.mb_v2_model)
-        q_model = quantizer()
+        quantizer.model = self.mb_v2_model
+        q_model = quantizer.fit()
         framework_specific_info = {"device": "cpu",
                      "approach": "post_training_static_quant",
                      "random_seed": 1234,
@@ -435,32 +448,36 @@ class TestAdaptorONNXRT(unittest.TestCase):
 
 
     def test_adaptor(self):
-        for fake_yaml in ["rename.yaml"]:
-            quantizer = Quantization(fake_yaml)
-            quantizer.calib_dataloader = self.rename_dataloader
-            quantizer.eval_dataloader = self.rename_dataloader
-            quantizer.model = common.Model(self.rename_model)
-            q_model = quantizer()
+        conf.model.framework = 'onnxrt_integerops'
+        conf.quantization.approach = 'post_training_dynamic_quant'
+        conf.quantization.calibration.sampling_size = 1
+        conf.evaluation.accuracy.metric = {'Accuracy': {}}
+        quantizer = Quantization()
+        quantizer = Quantization(conf)
+        quantizer.calib_dataloader = self.rename_dataloader
+        quantizer.eval_dataloader = self.rename_dataloader
+        quantizer.model = self.rename_model
+        q_model = quantizer.fit()
 
         for fake_yaml in ["static.yaml", "dynamic.yaml"]:
             quantizer = Quantization(fake_yaml)
             quantizer.calib_dataloader = self.cv_dataloader
             quantizer.eval_dataloader = self.cv_dataloader
-            quantizer.model = common.Model(self.rn50_model)
-            q_model = quantizer()
+            quantizer.model = self.rn50_model
+            q_model = quantizer.fit()
             eval_func(q_model)
 
         import copy
         tmp_model = copy.deepcopy(self.rn50_model)
         tmp_model.opset_import[0].version = 10
-        quantizer.model = common.Model(tmp_model)
-        q_model = quantizer()
+        quantizer.model = tmp_model
+        q_model = quantizer.fit()
         tmp_model.opset_import.extend([onnx.helper.make_opsetid("", 11)]) 
-        quantizer.model = common.Model(tmp_model)
-        q_model = quantizer()
+        quantizer.model = tmp_model
+        q_model = quantizer.fit()
         model = onnx.load('rn50_9.onnx')
-        quantizer.model = common.Model(model)
-        q_model = quantizer()
+        quantizer.model = model
+        q_model = quantizer.fit()
 
         framework_specific_info = {"device": "cpu",
                      "approach": "post_training_static_quant",
@@ -485,35 +502,35 @@ class TestAdaptorONNXRT(unittest.TestCase):
  
         for fake_yaml in ["gather.yaml"]:
             quantizer = Quantization(fake_yaml)
-            quantizer.model = common.Model(self.gather_model)
-            q_model = quantizer()
+            quantizer.model = self.gather_model
+            q_model = quantizer.fit()
 
-            quantizer.model = common.Model(self.matmul_model)
-            q_model = quantizer()
+            quantizer.model = self.matmul_model
+            q_model = quantizer.fit()
 
             quantizer.eval_dataloader = self.matmul_dataloader
-            q_model = quantizer()
+            q_model = quantizer.fit()
 
             quantizer.calib_dataloader = self.matmul_dataloader
             quantizer.eval_dataloader = self.matmul_dataloader
-            quantizer.model = common.Model(self.matmul_model)
-            q_model = quantizer()
+            quantizer.model = self.matmul_model
+            q_model = quantizer.fit()
 
         options.onnxrt.graph_optimization.level = 'ENABLE_BASIC'
         for fake_yaml in ["non_MSE.yaml"]:
             quantizer = Quantization(fake_yaml)
             quantizer.calib_dataloader = self.cv_dataloader
             quantizer.eval_dataloader = self.cv_dataloader
-            quantizer.model = common.Model(self.mb_v2_model)
-            q_model = quantizer()
+            quantizer.model = self.mb_v2_model
+            q_model = quantizer.fit()
             eval_func(q_model)
 
         for fake_yaml in ["static.yaml"]:
             quantizer = Quantization(fake_yaml)
             quantizer.calib_dataloader = self.ir3_dataloader
             quantizer.eval_dataloader = self.ir3_dataloader
-            quantizer.model = common.Model(self.ir3_model)
-            q_model = quantizer()
+            quantizer.model = self.ir3_model
+            q_model = quantizer.fit()
 
             from neural_compressor.utils.utility import recover
             model = recover(self.ir3_model, './nc_workspace/recover/history.snapshot', 0)
@@ -523,9 +540,37 @@ class TestAdaptorONNXRT(unittest.TestCase):
             fake_yaml = "benchmark.yaml"
             evaluator = Benchmark(fake_yaml)
             evaluator.b_dataloader = self.cv_dataloader
-            evaluator.model = common.Model(self.rn50_model)
+            evaluator.model = self.rn50_model
             evaluator(mode)
 
+    def test_lower_is_better_case(self):
+        import time
+        conf.model.framework = 'onnxrt_qlinearops'
+        conf.quantization.approach = 'post_training_static_quant'
+        conf.tuning.exit_policy.max_trials = 6
+        conf.tuning.accuracy_criterion.relative = 0.01
+        conf.tuning.accuracy_criterion.higher_is_better = False
+        conf.tuning.exit_policy.timeout = 100
+        
+        result = [0., 0.1, 0.102, 0.1006, 0.1005, 0.1004, 0.1002]
+        def sub_eval(model, result):
+            time.sleep(0.001 * len(result))
+            del result[0]
+            return result[0]
 
+        def eval(model):
+            return sub_eval(model, result)
+
+        from neural_compressor.experimental import Quantization
+        quantizer = Quantization(conf)
+        quantizer.model = self.matmul_model
+        quantizer.calib_dataloader = self.matmul_dataloader
+        quantizer.eval_func = eval
+        q_model = quantizer.fit()
+        node_names = [i.name for i in q_model.nodes()]
+        self.assertTrue('Matmul' in node_names)
+        self.assertTrue('add' in node_names)
+        self.assertTrue('add2_quant' in node_names)
+    
 if __name__ == "__main__":
     unittest.main()
