@@ -19,7 +19,10 @@ import numpy as np
 import yaml
 
 try:
-    import intel_pytorch_extension as ipex
+    try:
+        import intel_pytorch_extension as ipex
+    except:
+        import intel_extension_for_pytorch as ipex
     TEST_IPEX = True
 except:
     TEST_IPEX = False
@@ -311,7 +314,7 @@ class M(torch.nn.Module):
         super().__init__()
         self.quant = QuantStub()
         self.conv = nn.Conv2d(3, 1, 1)
-        self.linear = nn.Linear(224 * 224, 1)
+        self.linear = nn.Linear(224 * 224, 5)
         self.dequant = DeQuantStub()
 
     def forward(self, x):
@@ -324,6 +327,62 @@ class M(torch.nn.Module):
         return x
 
 
+class FP32Model(torch.nn.Module):
+    def __init__(self):
+        super().__init__()
+        self.conv = nn.Conv2d(1, 1, 1)
+    def forward(self, x):
+        x = self.conv(x)
+        return x
+
+
+class SubModel(torch.nn.Module):
+    def __init__(self):
+        super().__init__()
+        self.quant = QuantStub()
+        self.conv = nn.Conv2d(1, 1, 1)
+        self.conv1 = nn.Conv2d(1, 1, 1)
+        self.fp32 = FP32Model()
+        self.norm = nn.LayerNorm([1, 224, 224])
+        self.dequant = DeQuantStub()
+
+    def forward(self, x):
+        x = self.conv(x)
+        x = self.quant(x)
+        x = self.conv1(x)
+        x = self.dequant(x)
+        x = self.fp32(x)
+        x = self.norm(x)
+        return x
+
+
+class PartialQuantModel(torch.nn.Module):
+    def __init__(self):
+        super().__init__()
+        self.quant = QuantStub()
+        self.conv = nn.Conv2d(3, 1, 1)
+        self.bn = nn.BatchNorm2d(1)
+        self.conv1 = nn.Conv2d(1, 1, 1)
+        self.bn1 = nn.BatchNorm2d(1)
+        self.conv2 = nn.Conv2d(1, 1, 1)
+        self.linear = nn.Linear(224 * 224, 1)
+        self.dequant = DeQuantStub()
+        self.sub = SubModel()
+
+    def forward(self, x):
+        x = self.conv(x)
+        x = self.bn(x)
+        x = self.conv1(x)
+        x = self.bn1(x)
+        x = self.sub(x)
+        x = self.quant(x)
+        x = self.conv2(x)
+        x = x.view(1, -1)
+        x = self.linear(x)
+        x = self.dequant(x)
+        return x
+
+
 def eval_func(model):
     # switch to evaluate mode
     model.eval()
@@ -345,7 +404,7 @@ def q_func(model):
     optimizer.zero_grad()
     loss.backward()
     optimizer.step()
-    return
+    return model
 
 
 class TestPytorchAdaptor(unittest.TestCase):
@@ -409,11 +468,11 @@ class TestPytorchAdaptor(unittest.TestCase):
             if name == 'fc.bias':
                 tensor.grad = torch.zeros_like(tensor)
                 break
-        assert torch.equal(self.nc_model.get_gradient('fc.bias'), torch.zeros_like(tensor))
+        assert torch.equal(torch.Tensor(self.nc_model.get_gradient('fc.bias')), torch.zeros_like(tensor))
 
         rand_input = torch.rand(100, 3, 224, 224).float()
         rand_input.grad = torch.ones_like(rand_input)
-        assert torch.equal(self.nc_model.get_gradient(rand_input),
+        assert torch.equal(torch.Tensor(self.nc_model.get_gradient(rand_input)),
                            torch.ones_like(rand_input))
 
     def test_report_sparsity(self):
@@ -425,11 +484,12 @@ class TestPytorchAdaptor(unittest.TestCase):
         for fake_yaml in ['dynamic_yaml.yaml', 'qat_yaml.yaml', 'ptq_yaml.yaml']:
             model = M()
             quantizer = Quantization(fake_yaml)
+            quantizer.conf.usr_cfg.tuning.exit_policy['performance_only'] = True
             dataset = quantizer.dataset('dummy', (100, 3, 224, 224), label=True)
-            quantizer.model = common.Model(model)
+            quantizer.model = model
             quantizer.calib_dataloader = common.DataLoader(dataset)
             quantizer.eval_dataloader = common.DataLoader(dataset)
-            q_model = quantizer()
+            q_model = quantizer.fit()
             q_model.save('./saved')
             # Load configure and weights by neural_compressor.utils
             saved_model = load("./saved", model)
@@ -444,10 +504,10 @@ class TestPytorchAdaptor(unittest.TestCase):
         from neural_compressor.experimental import Benchmark
         evaluator = Benchmark('ptq_yaml.yaml')
         # Load configure and weights by neural_compressor.model
-        evaluator.model = common.Model(model)
+        evaluator.model = model
         evaluator.b_dataloader = common.DataLoader(dataset)
         evaluator()
-        evaluator.model = common.Model(model)
+        evaluator.model = model
         evaluator()
 
         for fake_yaml in ['qat_yaml.yaml', 'ptq_yaml.yaml']:
@@ -457,13 +517,13 @@ class TestPytorchAdaptor(unittest.TestCase):
             conf = Quantization_Conf(fake_yaml)
             quantizer = Quantization(conf)
             dataset = quantizer.dataset('dummy', (100, 3, 224, 224))
-            quantizer.model = common.Model(model)
+            quantizer.model = model
             if fake_yaml == 'qat_yaml.yaml':
                 quantizer.q_func = q_func
             else:
                 quantizer.calib_dataloader = common.DataLoader(dataset)
             quantizer.eval_func = eval_func
-            q_model = quantizer()
+            q_model = quantizer.fit()
             q_model.save('./saved')
             # Load configure and weights by neural_compressor.utils
             saved_model = load("./saved", model)
@@ -476,19 +536,39 @@ class TestPytorchAdaptor(unittest.TestCase):
             eval_func(saved_model)
             shutil.rmtree('./saved', ignore_errors=True)
 
+    def test_non_quant_module(self):
+        for fake_yaml in ['qat_yaml.yaml', 'ptq_yaml.yaml']:
+            model = PartialQuantModel()
+            conf = Quantization_Conf(fake_yaml)
+            quantizer = Quantization(conf)
+            dataset = quantizer.dataset('dummy', (1, 3, 224, 224))
+            non_quant_dict = {'non_quant_module_name': ['conv', 'conv1', 'sub.conv'], \
+                              'non_quant_module_class': ['BatchNorm2d', 'FP32Model']}
+            quantizer.model = common.Model(model, **non_quant_dict)
+            if fake_yaml == 'qat_yaml.yaml':
+                quantizer.q_func = q_func
+            else:
+                quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.eval_func = eval_func
+            q_model = quantizer.fit()
+            q_model.save('./saved')
+            saved_model = load("./saved", model, **non_quant_dict)
+            eval_func(saved_model)
+            shutil.rmtree('./saved', ignore_errors=True)
+
     def test_tensorboard(self):
         model = copy.deepcopy(self.nc_model)
         model.model.eval().fuse_model()
         quantizer = Quantization('dump_yaml.yaml')
         dataset = quantizer.dataset('dummy', (100, 3, 224, 224), label=True)
-        quantizer.model = common.Model(model.model)
+        quantizer.model = model.model
         quantizer.calib_dataloader = common.DataLoader(dataset)
         quantizer.eval_func = eval_func
-        quantizer()
+        quantizer.fit()
         self.assertTrue(True if os.path.exists('runs/eval/baseline_acc0.0') else False)
         quantizer.eval_dataloader = common.DataLoader(dataset)
         quantizer.eval_func = None
-        quantizer()
+        quantizer.fit()
         self.assertTrue(True if os.path.exists('runs/eval/baseline_acc0.0') else False)
 
     def test_tensor_dump_and_set(self):
@@ -500,8 +580,8 @@ class TestPytorchAdaptor(unittest.TestCase):
         dataloader = common._generate_common_dataloader(dataloader, 'pytorch')
         quantizer.eval_dataloader = dataloader
         quantizer.calib_dataloader = dataloader
-        quantizer.model = common.Model(model.model)
-        q_model = quantizer()
+        quantizer.model = model.model
+        q_model = quantizer.fit()
         quantizer.strategy.adaptor.inspect_tensor(
             model, dataloader, op_list=['conv1.0', 'layer1.0.conv1.0'],
             iteration_list=[1, 2], inspect_type='all', save_to_disk=True)
@@ -546,10 +626,10 @@ class TestPytorchAdaptor(unittest.TestCase):
 
         quantizer = Quantization('dynamic_yaml.yaml')
         model = dummymodel(vision_model)
-        quantizer.model = common.Model(model)
+        quantizer.model = model
         quantizer.calib_dataloader = dataloader
         quantizer.eval_dataloader = dataloader
-        quantizer()
+        quantizer.fit()
 
     def test_floatfunctions_fallback(self):
         class ModelWithFunctionals(torch.nn.Module):
@@ -593,7 +673,7 @@ class TestPytorchAdaptor(unittest.TestCase):
         if PT_VERSION >= PyTorchVersionMode.PT18.value:
             model.model.dequant.qconfig = torch.quantization.default_qconfig
         nc_torch._fallback_quantizable_ops_recursively(
-            model.model, '', fallback_ops, white_list=self.adaptor.white_list)
+            model.model, '', fallback_ops, op_qcfgs={})
         torch.quantization.add_observer_(model.model)
         model.model(x)
         torch.quantization.convert(model.model, self.adaptor.q_mapping, inplace=True)
@@ -618,11 +698,12 @@ class TestPytorchIPEXAdaptor(unittest.TestCase):
         from neural_compressor.experimental import Quantization
         model = M()
         quantizer = Quantization('ipex_yaml.yaml')
+        quantizer.conf.usr_cfg.tuning.exit_policy['performance_only'] = True
         dataset = quantizer.dataset('dummy', (100, 3, 224, 224), label=True)
-        quantizer.model = common.Model(model)
+        quantizer.model = model
         quantizer.calib_dataloader = common.DataLoader(dataset)
         quantizer.eval_dataloader = common.DataLoader(dataset)
-        nc_model = quantizer()
+        nc_model = quantizer.fit()
         nc_model.save('./saved')
         try:
             script_model = torch.jit.script(model.to(ipex.DEVICE))
@@ -630,7 +711,7 @@ class TestPytorchIPEXAdaptor(unittest.TestCase):
             script_model = torch.jit.trace(model.to(ipex.DEVICE), torch.randn(10, 3, 224, 224).to(ipex.DEVICE))
         from neural_compressor.experimental import Benchmark
         evaluator = Benchmark('ipex_yaml.yaml')
-        evaluator.model = common.Model(script_model)
+        evaluator.model = script_model
         evaluator.b_dataloader = common.DataLoader(dataset)
         results = evaluator()
 
@@ -665,7 +746,7 @@ class TestPytorchFXAdaptor(unittest.TestCase):
                                'convert_custom_config_dict': \
                                     {'preserved_attributes': []}
                               })
-            q_model = quantizer()
+            q_model = quantizer.fit()
             q_model.save('./saved')
             # Load configure and weights with neural_compressor.utils
             model_fx = load('./saved', model_origin,
@@ -691,6 +772,7 @@ class TestPytorchFXAdaptor(unittest.TestCase):
             model_origin = M()
             # run fx_quant in neural_compressor and save the quantized GraphModule
             quantizer = Quantization(fake_yaml)
+            quantizer.conf.usr_cfg.tuning.exit_policy['performance_only'] = True
             dataset = quantizer.dataset('dummy', (10, 3, 224, 224), label=True)
             quantizer.calib_dataloader = common.DataLoader(dataset)
             quantizer.eval_dataloader = common.DataLoader(dataset)
@@ -700,7 +782,7 @@ class TestPytorchFXAdaptor(unittest.TestCase):
                                'convert_custom_config_dict': \
                                     {'preserved_attributes': []}
                               })
-            q_model = quantizer()
+            q_model = quantizer.fit()
             q_model.save('./saved')
             # Load configure and weights with neural_compressor.utils
             model_fx = load('./saved', model_origin,
@@ -757,7 +839,7 @@ class TestPytorchFXAdaptor(unittest.TestCase):
                                'convert_custom_config_dict': \
                                     {'preserved_attributes': []}
                               })
-        q_model = quantizer()
+        q_model = quantizer.fit()
         q_model.save('./saved')
 
         # Load configure and weights by neural_compressor.utils
