@@ -15,7 +15,10 @@ import copy
 import numpy as np
 
 try:
-    import intel_pytorch_extension as ipex
+    try:
+        import intel_pytorch_extension as ipex
+    except:
+        import intel_extension_for_pytorch as ipex
     TEST_IPEX = True
 except:
     TEST_IPEX = False
@@ -167,10 +170,10 @@ class TestPytorchAdaptor(unittest.TestCase):
                 model.eval().fuse_model()
             quantizer = Quantization(fake_yaml)
             dataset = quantizer.dataset('dummy', (100, 3, 256, 256), label=True)
-            quantizer.model = common.Model(model)
+            quantizer.model = model
             quantizer.calib_dataloader = common.DataLoader(dataset)
             quantizer.eval_dataloader = common.DataLoader(dataset)
-            q_model = quantizer()
+            q_model = quantizer.fit()
         self.assertTrue(bool(q_model))
 
 
@@ -205,10 +208,10 @@ class TestPytorchFXAdaptor(unittest.TestCase):
         model.eval().fuse_model()
         quantizer = Quantization(fake_yaml)
         dataset = quantizer.dataset('dummy', (100, 3, 256, 256), label=True)
-        quantizer.model = common.Model(model)
+        quantizer.model = model
         quantizer.calib_dataloader = common.DataLoader(dataset)
         quantizer.eval_dataloader = common.DataLoader(dataset)
-        q_model = quantizer()
+        q_model = quantizer.fit()
         self.assertTrue(bool(q_model))
     
     @unittest.skipIf(PT_VERSION < PyTorchVersionMode.PT19.value,
@@ -219,10 +222,10 @@ class TestPytorchFXAdaptor(unittest.TestCase):
         model = torchvision.models.resnet18()
         quantizer = Quantization(fake_yaml)
         dataset = quantizer.dataset('dummy', (100, 3, 256, 256), label=True)
-        quantizer.model = common.Model(model)
+        quantizer.model = model
         quantizer.calib_dataloader = common.DataLoader(dataset)
         quantizer.eval_dataloader = common.DataLoader(dataset)
-        q_model = quantizer()
+        q_model = quantizer.fit()
         self.assertTrue(bool(q_model))
 
 
@@ -242,10 +245,10 @@ class TestPytorchIPEXAdaptor(unittest.TestCase):
         model = torchvision.models.resnet18()
         quantizer = Quantization('ipex_yaml.yaml')
         dataset = quantizer.dataset('dummy', (100, 3, 256, 256), label=True)
-        quantizer.model = common.Model(model)
+        quantizer.model = model
         quantizer.calib_dataloader = common.DataLoader(dataset)
         quantizer.eval_dataloader = common.DataLoader(dataset)
-        nc_model = quantizer()
+        nc_model = quantizer.fit()
         nc_model.save("./saved")
         try:
             script_model = torch.jit.script(model.to(ipex.DEVICE))
@@ -253,7 +256,7 @@ class TestPytorchIPEXAdaptor(unittest.TestCase):
             script_model = torch.jit.trace(model.to(ipex.DEVICE), torch.randn(10, 3, 224, 224).to(ipex.DEVICE))
         from neural_compressor.experimental import Benchmark
         evaluator = Benchmark('ipex_yaml.yaml')
-        evaluator.model = common.Model(script_model)
+        evaluator.model = script_model
         evaluator.b_dataloader = common.DataLoader(dataset)
         results = evaluator()
 
