@@ -324,7 +324,7 @@ class TestPruning(unittest.TestCase):
         from neural_compressor.experimental import Pruning, common
         prune = Pruning('fake.yaml')
         scheduler = Scheduler()
-        scheduler.model = common.Model(self.model)
+        scheduler.model = self.model
         datasets = DATASETS('pytorch')
         dummy_dataset = datasets['dummy'](shape=(100, 3, 224, 224), low=0., high=1., label=True)
         dummy_dataloader = PyTorchDataLoader(dummy_dataset)
@@ -356,15 +356,15 @@ class TestPruning(unittest.TestCase):
         prune.eval_dataloader = dummy_dataloader
         prune.train_dataloader = dummy_dataloader
         scheduler.append(prune)
-        opt_model = scheduler()
+        opt_model = scheduler.fit()
 
     def test_pure_yaml_pruning(self):
         from neural_compressor.experimental import Pruning, common
         prune = Pruning('fake2.yaml')
         scheduler = Scheduler()
-        scheduler.model = common.Model(self.model)
+        scheduler.model = self.model
         scheduler.append(prune)
-        opt_model = scheduler()
+        opt_model = scheduler.fit()
 
     def test_scheduler_qat_distillation(self):
         from neural_compressor.experimental import Quantization, common, Distillation
@@ -373,11 +373,11 @@ class TestPruning(unittest.TestCase):
         quantizer = Quantization('./fake3.yaml')
         distiller = Distillation('./fake6.yaml')
         scheduler = Scheduler()
-        scheduler.model = common.Model(self.q_model)
-        distiller.teacher_model = common.Model(self.q_model_teacher)
+        scheduler.model = self.q_model
+        distiller.teacher_model = self.q_model_teacher
         scheduler.append(distiller)
         scheduler.append(quantizer)
-        opt_model = scheduler()
+        opt_model = scheduler.fit()
 
     def test_combine_qat_pruning(self):
         from neural_compressor.experimental import Pruning, common, Quantization
@@ -386,10 +386,10 @@ class TestPruning(unittest.TestCase):
         quantizer = Quantization('./fake3.yaml')
         prune = Pruning('./fake2.yaml')
         scheduler = Scheduler()
-        scheduler.model = common.Model(self.q_model)
+        scheduler.model = self.q_model
         combination = scheduler.combine(prune, quantizer)
         scheduler.append(combination)
-        opt_model = scheduler()
+        opt_model = scheduler.fit()
         conv_weight = opt_model.model.layer1[0].conv1.weight().dequantize()
         self.assertAlmostEqual((conv_weight == 0).sum().item() / conv_weight.numel(),
                                0.97,
@@ -402,11 +402,11 @@ class TestPruning(unittest.TestCase):
         quantizer = Quantization('./fake3.yaml')
         distiller = Distillation('./fake6.yaml')
         scheduler = Scheduler()
-        scheduler.model = common.Model(self.q_model)
-        distiller.teacher_model = common.Model(self.q_model_teacher)
+        scheduler.model = self.q_model
+        distiller.teacher_model = self.q_model_teacher
         combination = scheduler.combine(distiller, quantizer)
         scheduler.append(combination)
-        opt_model = scheduler()
+        opt_model = scheduler.fit()
         self.assertEqual(combination.__repr__().lower(), 'combination of distillation,quantization')
 
     @unittest.skipIf(PT_VERSION < PyTorchVersionMode.PT19.value,
@@ -416,10 +416,10 @@ class TestPruning(unittest.TestCase):
         quantizer = Quantization('./fake5.yaml')
         prune = Pruning('./fake4.yaml')
         scheduler = Scheduler()
-        scheduler.model = common.Model(self.model)
+        scheduler.model = self.model
         combination = scheduler.combine(prune, quantizer)
         scheduler.append(combination)
-        opt_model = scheduler()
+        opt_model = scheduler.fit()
         conv_weight = dict(opt_model.model.layer1.named_modules())['0'].conv1.weight().dequantize()
         self.assertAlmostEqual((conv_weight == 0).sum().item() / conv_weight.numel(),
                                0.97,
