@@ -25,7 +25,7 @@ from neural_compressor.ux.components.configuration_wizard.configuration_parser i
 from neural_compressor.ux.utils.exceptions import ClientErrorException
 
 
-@patch("sys.argv", ["neural_compressor_bench.py", "-p5000"])
+@patch("sys.argv", ["inc_bench.py", "-p5000"])
 class TestParser(unittest.TestCase):
     """Main test class for parser."""
 
@@ -401,10 +401,10 @@ class TestDataloaderParser(TestParser):
             },
             {
                 "dtype": "float32",
-                "high": [127],
+                "high": [127.0],
                 "label": False,
-                "low": [-128],
-                "shape": [224, 224],
+                "low": [-128.0],
+                "shape": [[224, 224]],
             },
         )
 
@@ -421,10 +421,10 @@ class TestDataloaderParser(TestParser):
             },
             {
                 "dtype": "float32",
-                "high": [127],
+                "high": [127.0],
                 "label": False,
-                "low": [-128],
-                "shape": [224, 224],
+                "low": [-128.0],
+                "shape": [[224, 224]],
             },
         )
 
